@@ -5,9 +5,6 @@ knitr::opts_chunk$set(
 )
 
 ## ----setup, echo=FALSE--------------------------------------------------------
-library(formulaic)
-library(data.table)
-library(knitr)
 data("snack.dat", package = "formulaic")
 
 ## ----constant,echo=FALSE------------------------------------------------------
@@ -32,6 +29,7 @@ max.outcome.categories.to.search <- 4
 order.as <- "as.specified"
 include.backtick <- "as.needed"
 format.as <- "formula"
+
 force.main.effects <- TRUE
 
 ## ----example------------------------------------------------------------------
@@ -39,7 +37,7 @@ awareness.name = "Awareness"
 variable.names = c("Age", "Gender", "Income Group", "Region", "Persona", "Typo")
 
 ex.form <-
-  create.formula(outcome.name = awareness.name,
+  formulaic::create.formula(outcome.name = awareness.name,
                  input.names = 'variable.names',
                  dat = snack.dat)
 
@@ -51,56 +49,55 @@ summary(lm_example)
 user.outcome.name <- "Satisfaction"
 user.input.names <- c('Age Group', 'Gender', 'Region')
 
-create.formula(outcome.name = user.outcome.name, input.names = user.input.names)$formula
+formulaic::create.formula(outcome.name = user.outcome.name, input.names = user.input.names)$formula
 
 ## ----dataset------------------------------------------------------------------
 list(dim(snack.dat), names(snack.dat))
 
-## ----add.backtick example-----------------------------------------------------
-as.needed = formulaic:::add.backtick(x = names(snack.dat), include.backtick = 'as.needed')
-all = formulaic:::add.backtick(x = names(snack.dat), include.backtick = 'all')
+## ----formulaic::add.backtick example------------------------------------------
+as.needed = formulaic::add.backtick(x = names(snack.dat), include.backtick = 'as.needed')
+all = formulaic::add.backtick(x = names(snack.dat), include.backtick = 'all')
 
-library(DT)
-datatable(data = cbind(as.needed, all))
+data = cbind(as.needed, all)
 
-## ----add.backtick example 2---------------------------------------------------
-create.formula(outcome.name = awareness.name, input.names = variable.names)$formula
+## ----formulaic::add.backtick example 2----------------------------------------
+formulaic::create.formula(outcome.name = awareness.name, input.names = variable.names)$formula
 
-## ----add.backtick example 3---------------------------------------------------
-create.formula(
+## ----formulaic::add.backtick example 3----------------------------------------
+formulaic::create.formula(
   outcome.name = awareness.name,
   input.names = variable.names,
   format.as = "character",
   include.backtick = "all"
 )$formula
 
-## ----add.backtick example 4---------------------------------------------------
-create.formula(
+## ----formulaic::add.backtick example 4----------------------------------------
+formulaic::create.formula(
   outcome.name = awareness.name,
   input.names = variable.names,
   format.as = "character",
   include.backtick = "all"
 )$formula
 
-## ----create.formula examples basic--------------------------------------------
+## ----formulaic::create.formula examples basic---------------------------------
 
 input.names <-
   c("Age", "Gender", "Income", "Region", "Persona", "Typo")
 
 basic.form <-
-  create.formula(outcome.name = awareness.name,
+  formulaic::create.formula(outcome.name = awareness.name,
                  input.names = input.names,
                  dat = snack.dat)
 
 print(basic.form)
 
-## ----create.formula example interactions--------------------------------------
+## ----formulaic::create.formula example interactions---------------------------
 interactions = list(c("Age Group", "Gender"),
                     c("Age Group", "Region"),
                     c("Age Group", "Gender", "Region"))
 
 interaction.form <-
-  create.formula(
+  formulaic::create.formula(
     outcome.name = awareness.name,
     input.names = input.names,
     dat = snack.dat,
@@ -109,12 +106,12 @@ interaction.form <-
 
 print(interaction.form)
 
-## ----create.formula example input.patterns------------------------------------
+## ----formulaic::create.formula example input.patterns-------------------------
 bp.pattern = "BP_"
 input.patterns = c("Gend", bp.pattern)
 
 pattern.form <-
-  create.formula(
+  formulaic::create.formula(
     outcome.name = awareness.name,
     input.names = input.names,
     dat = snack.dat,
@@ -123,27 +120,27 @@ pattern.form <-
 
 print(pattern.form)
 
-## ----create.formula example dot.1---------------------------------------------
+## ----formulaic::create.formula example dot.1----------------------------------
 dot.form.1 <-
-  create.formula(outcome.name = awareness.name,
+  formulaic::create.formula(outcome.name = awareness.name,
                  input.names = ".",
                  dat = snack.dat)
 
 print(dot.form.1)
 
-## ----create.formula example dot.2---------------------------------------------
+## ----formulaic::create.formula example dot.2----------------------------------
 
 input.names = c("Gender", ".")
 
-dot.form.2 <- create.formula(outcome.name = awareness.name, input.names = input.names, dat = snack.dat)
+dot.form.2 <- formulaic::create.formula(outcome.name = awareness.name, input.names = input.names, dat = snack.dat)
 
 print(dot.form.2)
 
-## ----create.formula example dot.3---------------------------------------------
+## ----formulaic::create.formula example dot.3----------------------------------
 
 input.names = c("Typo", ".")
 
-dot.form.2 <- create.formula(outcome.name = awareness.name, input.names = input.names, dat = snack.dat)
+dot.form.2 <- formulaic::create.formula(outcome.name = awareness.name, input.names = input.names, dat = snack.dat)
 
 print(dot.form.2)
 
@@ -168,7 +165,7 @@ bp.pattern = "BP_"
 variables.to.exclude = c("BP_Delicious_0_10", "Gender")
 
 variables.to.exclude.form <-
-  create.formula(
+  formulaic::create.formula(
     outcome.name = awareness.name,
     input.names = input.names,
     interactions = interactions,
@@ -180,24 +177,24 @@ variables.to.exclude.form <-
 
 print(variables.to.exclude.form)
 
-## ----create.formula outcomes as inputs----------------------------------------
+## ----formulaic::create.formula outcomes as inputs-----------------------------
 input.names <- c("Income", "Age", "Income")
 income.name = "Income"
 
 outcomes.as.inputs.form <-
-  create.formula(outcome.name = income.name,
+  formulaic::create.formula(outcome.name = income.name,
                  input.names = input.names,
                  dat = snack.dat)
 
 print(outcomes.as.inputs.form)
 
-## ----create.formula example duplicated.inputs and interactions----------------
+## ----formulaic::create.formula example duplicated.inputs and interactions-----
 duplicated.inputs <- c(rep.int(x = "Age", times = 2), "Income")
 duplicated.interactions <-
   list(c("Age", "Income"), c("Age", "Income"))
 
 duplicated.form <-
-  create.formula(
+  formulaic::create.formula(
     outcome.name = awareness.name,
     input.names = duplicated.inputs,
     interactions = duplicated.interactions,
@@ -206,17 +203,17 @@ duplicated.form <-
 
 print(duplicated.form)
 
-## ----create.formula example with typo-----------------------------------------
+## ----formulaic::create.formula example with typo------------------------------
 input.names <- c("Age", "Typo")
 income.name <- "Income"
 
 formula.with.typo <-
-  create.formula(outcome.name = income.name, input.names = input.names)
+  formulaic::create.formula(outcome.name = income.name, input.names = input.names)
 print(formula.with.typo)
 
-## ----create.formula example without typo--------------------------------------
+## ----formulaic::create.formula example without typo---------------------------
 formula.without.typo <-
-  create.formula(outcome.name = income.name,
+  formulaic::create.formula(outcome.name = income.name,
                  input.names = input.names,
                  dat = snack.dat)
 print(formula.without.typo)
@@ -226,7 +223,7 @@ snack.dat[, .N, keyby = c("Awareness", "Consideration")]
 
 ## ----lack of contrast example numerical variables-----------------------------
 formula.consideration <-
-  create.formula(outcome.name = consideration.name,
+  formulaic::create.formula(outcome.name = consideration.name,
                  input.names = c(age.name, awareness.name))
 
 print(formula.consideration$formula)
@@ -235,9 +232,9 @@ glm(formula = formula.consideration,
     data = snack.dat,
     family = "binomial")$coefficients
 
-## ----create.formula with lack of contrast categorical 1-----------------------
+## ----formulaic::create.formula with lack of contrast categorical 1------------
 formula.consideration <-
-  create.formula(
+  formulaic::create.formula(
     outcome.name = consideration.name,
     input.names = c(age.name, awareness.name),
     dat = snack.dat,
@@ -248,16 +245,16 @@ print(formula.consideration)
 
 ## ----lack of contrast example categorical variables 0-------------------------
 formula.awareness <-
-  create.formula(outcome.name = awareness.name,
+  formulaic::create.formula(outcome.name = awareness.name,
                  input.names = c(age.group.name, gender.name))
 
 print(formula.awareness$formula)
 
-## ----create.formula with lack of contrast 2, eval=FALSE, include=TRUE---------
+## ----formulaic::create.formula with lack of contrast 2, eval=FALSE, include=TRUE----
 #  
 #  
 #  formula.awareness <-
-#    create.formula(
+#    formulaic::create.formula(
 #      outcome.name = awareness.name,
 #      input.names = c(age.group.name, gender.name),
 #      dat = snack.dat[get(age.group.name) == "[ 18, 35)", ],
@@ -268,7 +265,7 @@ print(formula.awareness$formula)
 
 ## ----create.fomula lack of contrast 3-----------------------------------------
 formula.consideration.1 <-
-  create.formula(
+  formulaic::create.formula(
     outcome.name = consideration.name,
     input.names = c(age.group.name, gender.name, awareness.name),
     dat = snack.dat,
@@ -278,9 +275,9 @@ formula.consideration.1 <-
 
 print(formula.consideration.1)
 
-## ----create.formula lack of contrast 4----------------------------------------
+## ----formulaic::create.formula lack of contrast 4-----------------------------
 formula.consideration.2 <-
-  create.formula(
+  formulaic::create.formula(
     outcome.name = consideration.name,
     input.names = c(age.group.name, gender.name, awareness.name),
     dat = snack.dat,
@@ -290,8 +287,8 @@ formula.consideration.2 <-
 
 print(formula.consideration.2)
 
-## ----create.formula large volume of categorical variables 01------------------
-create.formula(
+## ----formulaic::create.formula large volume of categorical variables 01-------
+formulaic::create.formula(
   outcome.name = satisfaction.name,
   input.names = c(age.name, income.name, region.name, id.name),
   dat = snack.dat,
@@ -299,8 +296,8 @@ create.formula(
   max.input.categories = 30
 )$formula
 
-## ----create.formula large volume of categorical variables---------------------
-create.formula(
+## ----formulaic::create.formula large volume of categorical variables----------
+formulaic::create.formula(
   outcome.name = awareness.name,
   input.names = ".",
   reduce = TRUE,
@@ -309,10 +306,10 @@ create.formula(
 )$formula
 
 
-## ----reduce.existing.formula example------------------------------------------
+## ----formulaic::reduce.existing.formula example-------------------------------
 the.initial.formula <- Awareness ~ .
 
-reduce.existing.formula(
+formulaic::reduce.existing.formula(
   the.initial.formula = the.initial.formula,
   dat = snack.dat,
   max.input.categories = 30
